@@ -1,12 +1,11 @@
 /* external string MACRO handling is broken under symbian^1 */
-#ifdef S60V5
-#warning "Working around broken external symbian1 string macros!!"
+#ifdef Q_OS_SYMBIAN
 #define APPNAME "cacheme"
-#define VERSION "0.8.9"
+#define VERSION "0.8.13"
 #define DATADIR "/data/cacheme"
 #define LIBDIR "/data/cacheme"
 #ifdef EXPIRATION_DATE
-#define EXPIRATION_DATE "01112011"
+#define EXPIRATION_DATE "01022012"
 #endif
 #endif
 
