@@ -10,14 +10,14 @@
 
 #include "iconloader.h"
 
-#ifdef Q_OS_SYMBIAN
+#ifdef SYMBIAN_BUTTON_INTERFACE
 #include <remconcoreapitargetobserver.h>    // link against RemConCoreApi.lib
 #include <remconcoreapitarget.h>            // and
 #include <remconinterfaceselector.h>        // RemConInterfaceBase.lib
 #endif
 
 class CustomWindow : public QMainWindow
-#ifdef Q_OS_SYMBIAN
+#ifdef SYMBIAN_BUTTON_INTERFACE
 , public MRemConCoreApiTargetObserver 
 #endif
 {
@@ -28,12 +28,15 @@ class CustomWindow : public QMainWindow
   ~CustomWindow();
   void setCentralWidget(QWidget *);
   void setWindowTitle(const QString &);
+  void addMenuEntry(const QString &, QObject *, const char *);
+  void reParent(CustomWindow *);
 
-#ifdef Q_OS_SYMBIAN
+#ifdef SYMBIAN_BUTTON_INTERFACE
   virtual void MrccatoCommand(TRemConCoreApiOperationId aOperationId,
 			      TRemConCoreApiButtonAction aButtonAct);
+  void grabSpecialKeys(bool);
 #endif
-
+  
  protected:
   void keyPressEvent(QKeyEvent*);
 
@@ -54,8 +57,13 @@ class CustomWindow : public QMainWindow
   IconLoader *m_iconLoader;
   QVBoxLayout *m_layout;
   QLabel *m_title;
+  CustomWindow *m_parent;
+
+#ifdef SYMBIAN_BUTTON_INTERFACE
+  // since the button interface can only be linked to 
+  // one window, we need to keep information on the top window
+  QList <CustomWindow*> m_children;
 
-#ifdef Q_OS_SYMBIAN
   CRemConInterfaceSelector* iInterfaceSelector;
   CRemConCoreApiTarget*     iCoreTarget;
 #endif
