@@ -3,6 +3,7 @@
 
 #include <QTextBrowser>
 #include <QNetworkReply>
+#include <QLabel>
 #include <QMap>
 
 #include "cache.h"
@@ -27,6 +28,8 @@ class HtmlView : public QTextBrowser {
 };
 
 class FixHtmlView : public HtmlView {
+  Q_OBJECT;
+
  public:
   FixHtmlView(const Description &, QWidget *);
 
@@ -39,4 +42,9 @@ class FixHtmlView : public HtmlView {
   int m_width;
 };
 
+class HtmlLabel : public QLabel {
+ public:
+  HtmlLabel(const Description &, QWidget *);
+};
+
 #endif // HTMLVIEW_H
