@@ -12,6 +12,7 @@
 #include "iconloader.h"  
 #include "cachewindow.h"
 #include "config.h"
+#include "tool.h"
 
 #include <QIcon>
 #include <QSettings>
@@ -22,12 +23,39 @@
 #include <QMaemo5InformationBox>
 #endif
 
+#include "tool_rot13.h"
+#include "tool_projection.h"
+
+void MainWindow::launchToolRot13() {
+  ToolRot13 *tool = new ToolRot13(this);
+  tool->show();
+}
+
+void MainWindow::launchToolProjection() {
+  ToolProjection *tool = new ToolProjection(m_mapWidget, m_wptDb, this);
+  tool->show();
+}
+
+void MainWindow::enableToolProjection(bool on) {
+  qDebug() << __FUNCTION__ << on;
+
+  if(m_ActionToolProjection)
+    m_ActionToolProjection->setEnabled(on);
+}
+
 void MainWindow::createMenu() {
+
   addMenuEntry(tr("&About"), this, SLOT(about()));
   addMenuEntry(tr("&Settings"), this, SLOT(settingsdialog()));
 
   /* create a submenu for the plugin selection */  
   m_cacheProvider->createMenu(menuBar());
+
+  /* add tools to the tools menu */
+  QMenu *toolsMenu = menuBar()->addMenu(tr("&Tools"));
+  ToolRot13::registerMenu(toolsMenu, this, SLOT(launchToolRot13()));
+  m_ActionToolProjection = ToolProjection::registerMenu(toolsMenu, this, SLOT(launchToolProjection()));
+  m_ActionToolProjection->setEnabled(false);
 }
 
 void MainWindow::settingsdialog() {
@@ -78,7 +106,7 @@ void MainWindow::about() {
 
 MainWindow::MainWindow(LocationProvider *locationProvider, QWidget *parent) : 
   CustomWindow("MainWindow", parent), m_locationProvider(locationProvider),
-  m_lastFlags(0) {
+  m_lastFlags(0), m_ActionToolProjection(NULL) {
 
   qDebug() << __FUNCTION__;
   m_cacheProvider = new CacheProvider(this);
@@ -104,9 +132,13 @@ MainWindow::MainWindow(LocationProvider *locationProvider, QWidget *parent) :
   QString serviceProviderStr = settings.value("Service", "nokia").toString();
   settings.endGroup();
 
-  this->m_serviceProvider = new QGeoServiceProvider(serviceProviderStr);
+  // give app id key to service provider
+  QMap<QString, QVariant> params;
+  params.insert("mapping.app_id", "athGTWaNTNPAgYYwbBLh");
+  
+  this->m_serviceProvider = new QGeoServiceProvider(serviceProviderStr, params);
   if(!this->m_serviceProvider->mappingManager())
-    this->m_serviceProvider = new QGeoServiceProvider("nokia");
+    this->m_serviceProvider = new QGeoServiceProvider("nokia", params);
 
   this->m_mapWidget = new MapWidget(this->m_serviceProvider->mappingManager());
 
@@ -143,6 +175,9 @@ MainWindow::MainWindow(LocationProvider *locationProvider, QWidget *parent) :
   QObject::connect(this->m_mapWidget, SIGNAL(showMessage(const QString &)),
 		   this, SLOT(statusMessage(const QString &)));
 
+  QObject::connect(this->m_mapWidget, SIGNAL(cacheIsSelected(bool)),
+		   this, SLOT(enableToolProjection(bool)));
+
   QObject::connect(this, SIGNAL(zoomInPressed()),
 		   this->m_mapWidget, SLOT(zoomIn()));
 
@@ -250,7 +285,7 @@ void MainWindow::showDetail(const Cache &cache) {
   qDebug() << __FUNCTION__;
 
   CacheWindow *cacheWindow = 
-    new CacheWindow(cache, m_locationProvider, m_wptDb, this);
+    new CacheWindow(cache, m_locationProvider, m_wptDb, m_mapWidget, this);
   cacheWindow->show();
 }
 
