@@ -27,7 +27,7 @@ void SwapBox::resizeEvent(QResizeEvent *) {
   bool landscape = 
     window()->size().width() > window()->size().height();
 
-  qDebug() << __FUNCTION__ << window()->size() << landscape;
+  //  qDebug() << __FUNCTION__ << window()->size() << landscape;
   
   m_layout->setDirection(landscape?
 			 QBoxLayout::LeftToRight:
