@@ -4,7 +4,7 @@
 <context>
     <name>AttributeWindow</name>
     <message>
-        <location filename="../src/attributewindow.cpp" line="23"/>
+        <location filename="../src/attributewindow.cpp" line="22"/>
         <source>Attributes</source>
         <translation>Attribute</translation>
     </message>
@@ -36,27 +36,27 @@
         <translation type="obsolete">Behälter</translation>
     </message>
     <message>
-        <location filename="../src/cachewindow.cpp" line="170"/>
+        <location filename="../src/cachewindow.cpp" line="156"/>
         <source>Description</source>
         <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="../src/cachewindow.cpp" line="180"/>
+        <location filename="../src/cachewindow.cpp" line="166"/>
         <source>Navigation</source>
         <translation>Navigation</translation>
     </message>
     <message>
-        <location filename="../src/cachewindow.cpp" line="190"/>
+        <location filename="../src/cachewindow.cpp" line="176"/>
         <source>Hint</source>
         <translation>Hinweis</translation>
     </message>
     <message>
-        <location filename="../src/cachewindow.cpp" line="200"/>
+        <location filename="../src/cachewindow.cpp" line="186"/>
         <source>Logs</source>
         <translation>Logs</translation>
     </message>
     <message>
-        <location filename="../src/cachewindow.cpp" line="210"/>
+        <location filename="../src/cachewindow.cpp" line="196"/>
         <source>Attributes</source>
         <translation>Attribute</translation>
     </message>
@@ -68,77 +68,89 @@
 <context>
     <name>CoordinateTool</name>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="125"/>
+        <location filename="../src/coordinatetool.cpp" line="102"/>
         <source>New waypoint</source>
         <translation>Neuer Wegpunkt</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="136"/>
+        <location filename="../src/coordinatetool.cpp" line="113"/>
         <source>Name:</source>
         <translation>Name:</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="145"/>
+        <location filename="../src/coordinatetool.cpp" line="122"/>
         <source>Description:</source>
         <translation>Beschreibung:</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="170"/>
+        <location filename="../src/coordinatetool.cpp" line="147"/>
         <source>New Coordinate</source>
         <translation>Neue Koordinate</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="171"/>
+        <location filename="../src/coordinatetool.cpp" line="148"/>
         <source>Edit Coordinate</source>
         <translation>Koordinate bearbeiten</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="334"/>
+        <location filename="../src/coordinatetool.cpp" line="311"/>
         <source>S</source>
         <translation>S</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="335"/>
+        <location filename="../src/coordinatetool.cpp" line="312"/>
         <source>N</source>
         <translation>N</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="351"/>
+        <location filename="../src/coordinatetool.cpp" line="328"/>
         <source>W</source>
         <translation>W</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="352"/>
+        <location filename="../src/coordinatetool.cpp" line="329"/>
         <source>E</source>
         <translation>O</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="439"/>
+        <location filename="../src/coordinatetool.cpp" line="355"/>
+        <location filename="../src/coordinatetool.cpp" line="463"/>
+        <source>Map Center</source>
+        <translation>Kartenzentrum</translation>
+    </message>
+    <message>
+        <location filename="../src/coordinatetool.cpp" line="357"/>
+        <location filename="../src/coordinatetool.cpp" line="468"/>
+        <source>GPS Position</source>
+        <translation>GPS-Position</translation>
+    </message>
+    <message>
+        <location filename="../src/coordinatetool.cpp" line="424"/>
         <source>New</source>
         <translation>Neu</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="442"/>
+        <location filename="../src/coordinatetool.cpp" line="427"/>
         <source>Edit</source>
         <translation>Bearbeiten</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="446"/>
+        <location filename="../src/coordinatetool.cpp" line="431"/>
         <source>Delete</source>
         <translation>Löschen</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="450"/>
+        <location filename="../src/coordinatetool.cpp" line="435"/>
         <source>Copy to clipboard</source>
         <translation>Kopiere in Zwischenablage</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="487"/>
+        <location filename="../src/coordinatetool.cpp" line="482"/>
         <source>Latitude</source>
         <translation>Breite</translation>
     </message>
     <message>
-        <location filename="../src/coordinatetool.cpp" line="492"/>
+        <location filename="../src/coordinatetool.cpp" line="487"/>
         <source>Longitude</source>
         <translation>Länge</translation>
     </message>
@@ -159,6 +171,34 @@
         <translation>Im Browser öffnen</translation>
     </message>
 </context>
+<context>
+    <name>DistanceWidget</name>
+    <message>
+        <location filename="../src/distancewidget.cpp" line="58"/>
+        <source>m</source>
+        <translation>m</translation>
+    </message>
+    <message>
+        <location filename="../src/distancewidget.cpp" line="59"/>
+        <source>km</source>
+        <translation>km</translation>
+    </message>
+    <message>
+        <location filename="../src/distancewidget.cpp" line="60"/>
+        <source>ft</source>
+        <translation>ft</translation>
+    </message>
+    <message>
+        <location filename="../src/distancewidget.cpp" line="61"/>
+        <source>yd</source>
+        <translation>yd</translation>
+    </message>
+    <message>
+        <location filename="../src/distancewidget.cpp" line="62"/>
+        <source>mi</source>
+        <translation>mi</translation>
+    </message>
+</context>
 <context>
     <name>GcBrowser</name>
     <message>
@@ -345,7 +385,7 @@
 <context>
     <name>HintWindow</name>
     <message>
-        <location filename="../src/cachewindow.cpp" line="30"/>
+        <location filename="../src/hintwindow.cpp" line="10"/>
         <source>Hint</source>
         <translation>Hinweis</translation>
     </message>
@@ -353,7 +393,7 @@
 <context>
     <name>LogWidget</name>
     <message>
-        <location filename="../src/logwindow.cpp" line="27"/>
+        <location filename="../src/logwindow.cpp" line="32"/>
         <source>by</source>
         <translation>von</translation>
     </message>
@@ -361,12 +401,12 @@
 <context>
     <name>LogWindow</name>
     <message>
-        <location filename="../src/logwindow.cpp" line="45"/>
+        <location filename="../src/logwindow.cpp" line="50"/>
         <source>Logs</source>
         <translation>Logs</translation>
     </message>
     <message>
-        <location filename="../src/logwindow.cpp" line="59"/>
+        <location filename="../src/logwindow.cpp" line="64"/>
         <source>Create new log</source>
         <translation>Neuen Log-Eintrag erstellen</translation>
     </message>
@@ -394,60 +434,69 @@
         <translation type="obsolete">&amp;Hilfe</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="27"/>
+        <location filename="../src/mainwindow.cpp" line="49"/>
         <source>&amp;Settings</source>
         <translation>&amp;Einstellungen</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="26"/>
+        <location filename="../src/mainwindow.cpp" line="48"/>
         <source>&amp;About</source>
         <translation>&amp;Über</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="53"/>
+        <location filename="../src/mainwindow.cpp" line="55"/>
+        <source>&amp;Tools</source>
+        <translation>&amp;Werkzeuge</translation>
+    </message>
+    <message>
+        <source>&amp;Rot13/Cesar</source>
+        <translation type="obsolete">&amp;Rot13/Cäsar</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="81"/>
         <source>Help</source>
         <translation>Hilfe</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="70"/>
+        <location filename="../src/mainwindow.cpp" line="98"/>
         <source>About CacheMe</source>
         <translation>Über CacheMe</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="71"/>
-        <location filename="../src/mainwindow.cpp" line="86"/>
+        <location filename="../src/mainwindow.cpp" line="99"/>
+        <location filename="../src/mainwindow.cpp" line="114"/>
         <source>CacheMe</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="71"/>
+        <location filename="../src/mainwindow.cpp" line="99"/>
         <source>Version</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="72"/>
+        <location filename="../src/mainwindow.cpp" line="100"/>
         <source>Build date:</source>
         <translation>Erstellungsdatum:</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="73"/>
+        <location filename="../src/mainwindow.cpp" line="101"/>
         <source>(c) 2011 by Till Harbaum &lt;till@harbaum.org&gt;</source>
         <oldsource>(c) 2011 by Till Harbaum &lt;till@harbaum.org&gt;
 </oldsource>
         <translation>(c) 2011 von Till Harbaum &lt;till@harbaum.org&gt;</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="74"/>
+        <location filename="../src/mainwindow.cpp" line="102"/>
         <source>CacheMe is an online geocaching application.</source>
         <translation>CacheMe ist eine Online-Geocaching-Anwendung.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="184"/>
+        <location filename="../src/mainwindow.cpp" line="219"/>
         <source>This copy of CacheMe has expired and will close in one minute!</source>
         <translation>Diese Kopie von CacheMe ist abgelaufen und wird in einer Minute geschlossen!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="187"/>
+        <location filename="../src/mainwindow.cpp" line="222"/>
         <source>This copy of CacheMe will expire in %1 days!</source>
         <translation>Diese Kopie von CacheMe läuft in %1 Tagen aus!</translation>
     </message>
@@ -506,15 +555,24 @@
         <translation type="obsolete">Öffne &quot;%1&quot; im Browser ...</translation>
     </message>
     <message>
-        <location filename="../src/mapwidget.cpp" line="433"/>
+        <location filename="../src/mapwidget.cpp" line="449"/>
         <source>Displayed cache data is %1 weeks old!</source>
         <translation>Angezeigte Cache-Daten sind %1 Wochen alt!</translation>
     </message>
+    <message>
+        <location filename="../src/mapwidget.cpp" line="455"/>
+        <source>Limiting number of displayed caches</source>
+        <translation>Anzahl angezeigter Caches begrenzt</translation>
+    </message>
+    <message>
+        <source>Limiting number of caches displayed</source>
+        <translation type="obsolete">Anzahl angezeigter Caches begrenzt</translation>
+    </message>
 </context>
 <context>
     <name>NavigationWindow</name>
     <message>
-        <location filename="../src/navigationwindow.cpp" line="111"/>
+        <location filename="../src/navigationwindow.cpp" line="59"/>
         <source>Distance</source>
         <translation>Entfernung</translation>
     </message>
@@ -523,21 +581,26 @@
         <translation type="obsolete">Aktuelle Koordinate:</translation>
     </message>
     <message>
-        <location filename="../src/navigationwindow.cpp" line="100"/>
+        <location filename="../src/navigationwindow.cpp" line="45"/>
         <source>Latitude</source>
         <translation>Breite</translation>
     </message>
     <message>
-        <location filename="../src/navigationwindow.cpp" line="102"/>
+        <location filename="../src/navigationwindow.cpp" line="47"/>
         <source>Longitude</source>
         <translation>Länge</translation>
     </message>
+    <message>
+        <location filename="../src/navigationwindow.cpp" line="49"/>
+        <source>Precision</source>
+        <translation>Genauigkeit</translation>
+    </message>
     <message>
         <source>Cache coordinate:</source>
         <translation type="obsolete">Cache-Koordinate:</translation>
     </message>
     <message>
-        <location filename="../src/navigationwindow.cpp" line="77"/>
+        <location filename="../src/navigationwindow.cpp" line="19"/>
         <source>Navigation</source>
         <translation>Navigation</translation>
     </message>
@@ -1319,6 +1382,16 @@ Quazip-Teile Copyright 2005 durch Sergey A. Tachenov</translation>
         <source>Unsupported file type: %2</source>
         <translation type="obsolete">Nicht unterstützter Dateityp: %2</translation>
     </message>
+    <message>
+        <location filename="../src/tool_projection.cpp" line="167"/>
+        <source>&amp;Projection</source>
+        <translation>&amp;Projektion</translation>
+    </message>
+    <message>
+        <location filename="../src/tool_rot13.cpp" line="122"/>
+        <source>&amp;Rot13/Cesar</source>
+        <translation>&amp;Rot13/Cäsar</translation>
+    </message>
 </context>
 <context>
     <name>QuaZipFile</name>
@@ -1331,104 +1404,104 @@ Quazip-Teile Copyright 2005 durch Sergey A. Tachenov</translation>
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="202"/>
+        <location filename="../src/settingsdialog.cpp" line="210"/>
         <source>Settings</source>
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="103"/>
+        <location filename="../src/settingsdialog.cpp" line="104"/>
         <source>Type</source>
         <translation>Typ</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="97"/>
+        <location filename="../src/settingsdialog.cpp" line="98"/>
         <source>Hybrid Map</source>
         <translation>Hybridkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="97"/>
+        <location filename="../src/settingsdialog.cpp" line="98"/>
         <source>Transit Map</source>
         <translation>ÖPNV-Karte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="98"/>
+        <location filename="../src/settingsdialog.cpp" line="99"/>
         <source>Gray Street Map</source>
         <translation>Graue Straßenkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="98"/>
+        <location filename="../src/settingsdialog.cpp" line="99"/>
         <source>Mobile Street Map</source>
         <translation>Mobile Straßenkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="99"/>
+        <location filename="../src/settingsdialog.cpp" line="100"/>
         <source>Mobile Terrain Map</source>
         <translation>Mobile Geländekarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="99"/>
+        <location filename="../src/settingsdialog.cpp" line="100"/>
         <source>Mobile Hybrid Map</source>
         <translation>Mobile Hybridkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="100"/>
+        <location filename="../src/settingsdialog.cpp" line="101"/>
         <source>Mobile Transit Map</source>
         <translation>Mobile ÖPNV-Karte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="100"/>
+        <location filename="../src/settingsdialog.cpp" line="101"/>
         <source>Mobile Gray Street Map</source>
         <translation>Mobile graue Straßenkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="122"/>
+        <location filename="../src/settingsdialog.cpp" line="123"/>
         <source>Service</source>
         <translation>Dienst</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="141"/>
+        <location filename="../src/settingsdialog.cpp" line="142"/>
         <source>Bigger icons</source>
         <translation>Große Icons</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="146"/>
+        <location filename="../src/settingsdialog.cpp" line="147"/>
         <source>Hide owned/found</source>
         <translation>Eigene/gefundene verstecken</translation>
     </message>
     <message>
         <location filename="../src/settingsdialog.cpp" line="87"/>
-        <location filename="../src/settingsdialog.cpp" line="209"/>
+        <location filename="../src/settingsdialog.cpp" line="219"/>
         <source>Map</source>
         <translation>Karte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="151"/>
+        <location filename="../src/settingsdialog.cpp" line="152"/>
         <source>Disable Screensaver</source>
         <translation>Bildschirmschoner aus</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="164"/>
-        <location filename="../src/settingsdialog.cpp" line="210"/>
+        <location filename="../src/settingsdialog.cpp" line="165"/>
+        <location filename="../src/settingsdialog.cpp" line="220"/>
         <source>Account</source>
         <translation>Zugang</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="95"/>
+        <location filename="../src/settingsdialog.cpp" line="96"/>
         <source>Street Map</source>
         <translation>Straßenkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="95"/>
+        <location filename="../src/settingsdialog.cpp" line="96"/>
         <source>Satellite Map Day</source>
         <translation>Satellitenkarte Tag</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="96"/>
+        <location filename="../src/settingsdialog.cpp" line="97"/>
         <source>Satellite Map Night</source>
         <translation>Satellitenkarte Nacht</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="96"/>
+        <location filename="../src/settingsdialog.cpp" line="97"/>
         <source>Terrain Map</source>
         <translation>Geländekarte</translation>
     </message>
@@ -1441,7 +1514,7 @@ Quazip-Teile Copyright 2005 durch Sergey A. Tachenov</translation>
         <translation type="obsolete">Kartendienst</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="135"/>
+        <location filename="../src/settingsdialog.cpp" line="136"/>
         <source>A change of the map service takes effect after restart.</source>
         <translation>Ein Wechsel des Kartendienstes wird erst nach einem Neustart aktiv.</translation>
     </message>
@@ -1450,19 +1523,71 @@ Quazip-Teile Copyright 2005 durch Sergey A. Tachenov</translation>
         <translation type="obsolete">Hoch auflösender Bildschirm</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="175"/>
+        <location filename="../src/settingsdialog.cpp" line="177"/>
         <source>Geocaching.com account</source>
         <translation>Geocaching.com-Zugang</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="180"/>
+        <location filename="../src/settingsdialog.cpp" line="184"/>
         <source>Username</source>
         <translation>Benutzername</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="185"/>
+        <location filename="../src/settingsdialog.cpp" line="191"/>
         <source>Password</source>
         <translation>Passwort</translation>
     </message>
 </context>
+<context>
+    <name>ToolProjection</name>
+    <message>
+        <location filename="../src/tool_projection.cpp" line="62"/>
+        <location filename="../src/tool_projection.cpp" line="66"/>
+        <source>Projection</source>
+        <translation>Projektion</translation>
+    </message>
+    <message>
+        <location filename="../src/tool_projection.cpp" line="90"/>
+        <source>Distance</source>
+        <translation>Entfernung</translation>
+    </message>
+    <message>
+        <location filename="../src/tool_projection.cpp" line="101"/>
+        <source>Direction</source>
+        <translation>Richtung</translation>
+    </message>
+    <message>
+        <location filename="../src/tool_projection.cpp" line="130"/>
+        <source>Result</source>
+        <translation>Egebnis</translation>
+    </message>
+    <message>
+        <location filename="../src/tool_projection.cpp" line="131"/>
+        <source>Latitude</source>
+        <translation>Breite</translation>
+    </message>
+    <message>
+        <location filename="../src/tool_projection.cpp" line="133"/>
+        <source>Longitude</source>
+        <translation>Länge</translation>
+    </message>
+    <message>
+        <location filename="../src/tool_projection.cpp" line="138"/>
+        <source>Create Waypoint</source>
+        <translation>Wegpunkt anlegen</translation>
+    </message>
+</context>
+<context>
+    <name>ToolRot13</name>
+    <message>
+        <location filename="../src/tool_rot13.cpp" line="62"/>
+        <source>Rot13/Cesar</source>
+        <translation>Rot13/Cäsar</translation>
+    </message>
+    <message>
+        <location filename="../src/tool_rot13.cpp" line="97"/>
+        <source>Rot13</source>
+        <translation>Rot13</translation>
+    </message>
+</context>
 </TS>
