@@ -4,7 +4,7 @@
 #include <QObject>
 #include <QNetworkReply>
 
-#include "cache.h"
+#include "cachelist.h"
 #include "cacheproviderplugin.h"
 
 class GcBrowser : public QObject, public CacheProviderPlugin {
@@ -26,7 +26,7 @@ public:
   void createConfig(QDialog *, QVBoxLayout*);
 
   bool busy();
-  void processRequestOverview(const QGeoBoundingBox &);
+  void processRequestOverview(const QGeoBoundingBox &, const int);
   void processRequestInfo(const QString &);
   void processRequestDetail(const QString &);
 
@@ -73,6 +73,15 @@ public:
   QString m_name, m_password;
   CurrentRequest m_currentRequest;
   QString m_posted;
+
+  // we save the list of waypoints for last detail request since the
+  // overview request may not return them
+  QString m_lastWaypointsName;
+  QList<Waypoint> m_lastWaypoints;
+  bool m_pendingReload;
+
+  // keep internal list to reduce number of net requests
+  QGeoBoundingBox m_cacheBox;
 };
 
 #endif // GCBROWSER_H
