@@ -4,7 +4,7 @@
 #include <QObject>
 #include <QThread>
 
-#include "cache.h"
+#include "cachelist.h"
 #include "cacheproviderplugin.h"
 #include "gpxfileparser.h"
 
