@@ -76,8 +76,7 @@ static void deleteCacheDirectory(QString cacheDir) {
 QGeoMappingManagerEngineOsm::QGeoMappingManagerEngineOsm(const QMap<QString, QVariant> &parameters, QGeoServiceProvider::Error *error, QString *errorString)
         : QGeoTiledMappingManagerEngine(parameters),
         m_parameters(parameters),
-//        m_host("tile.openstreetmap.org")
-        m_host("b.tile.cloudmade.com")
+        m_host("tile.openstreetmap.org")
 {
     Q_UNUSED(error)
     Q_UNUSED(errorString)
@@ -168,27 +167,10 @@ QGeoTiledMapReply* QGeoMappingManagerEngineOsm::getTileImage(const QGeoTiledMapR
 
 QString QGeoMappingManagerEngineOsm::getRequestString(const QGeoTiledMapRequest &request) const
 {
-    QString requestString = "http://";
-    QString apiKey = "BC9A493B41014CAABB98F0471D759707";
-    //QString tileStyleId = m_tyleStyleId;
-    QString tileDimension = "256";
-    requestString += m_host;
-    requestString += '/';
-    requestString += apiKey;
-    requestString += '/';
-    requestString += m_tyleStyleId;
-    requestString += '/';
-    requestString += tileDimension;
-    requestString += '/';
-    requestString += QString::number(request.zoomLevel());
-    requestString += '/';
-    requestString += QString::number(request.column());
-    requestString += '/';
-    requestString += QString::number(request.row());
-    requestString += '.';
-    requestString += "png";
-
-    return requestString;
+  return QString("http://" + m_host + "/" + 
+		 QString::number(request.zoomLevel()) + "/"+
+		 QString::number(request.column()) + "/" +
+		 QString::number(request.row()) + ".png");
 }
 
 void QGeoMappingManagerEngineOsm::setOption(/*QString optionName, QString optionValue*/)
