@@ -29,6 +29,13 @@ Compass::Compass(const Cache &cache, QWidget *parent) :
   setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
 }
 
+#if 0
+// the compass should be at least 200x200 pixels in size
+QSize Compass::sizeHint() const {
+  return QSize(200, 200);
+}
+#endif
+
 Compass::~Compass() {
   qDebug() << __FUNCTION__;
   
@@ -223,3 +230,7 @@ void Compass::setType(const Waypoint &wpt) {
   load(m_cacheRenderer, wpt.iconFile());
   update();
 }
+
+int Compass::heightForWidth(int w) const {
+  return w;
+}
