@@ -72,6 +72,11 @@ void GpsdPositionInfoSource::parse(const QString &str) {
       map.value("proto_major").toString() + "." + 
       map.value("proto_minor").toString();
 
+    if(m_delayedStart) {
+      startUpdates();
+      m_delayedStart = false;
+    }
+
   } else if(!classStr.compare("TPV")) {
     // TPV is the most interesting string for us
     m_lastKnown = QGeoPositionInfo();
@@ -123,6 +128,8 @@ GpsdPositionInfoSource::GpsdPositionInfoSource(QObject *parent)
   : QGeoPositionInfoSource(parent) {
   qDebug() << __FUNCTION__;
 
+  m_delayedStart = false;
+
   // connect to gpsd
   m_tcpSocket = new QTcpSocket(this);
 
@@ -151,7 +158,8 @@ void GpsdPositionInfoSource::startUpdates() {
     // request info from gpsd
     QString request = "?WATCH={\"enable\":true,\"json\":true}";
     m_tcpSocket->write(request.toUtf8());
-  }
+  } else
+    m_delayedStart = true;
 }
 
 void GpsdPositionInfoSource::stopUpdates() {
@@ -159,7 +167,8 @@ void GpsdPositionInfoSource::stopUpdates() {
     // ask gpsd to stop sending data
     QString request = "?WATCH={\"enable\":false}";
     m_tcpSocket->write(request.toUtf8());
-  }
+  } else
+    m_delayedStart = false;
 }
 
 void GpsdPositionInfoSource::requestUpdate(int) {
