@@ -9,9 +9,10 @@
 #include "customwindow.h"
 #include "locationprovider.h"
 #include "mapwidget.h"
-#include "cache.h"
+#include "cachelist.h"
 #include "cacheprovider.h"
 #include "waypointdb.h"
+#include "tool.h"
 
 class MainWindow : public CustomWindow {
   Q_OBJECT;
@@ -36,12 +37,15 @@ class MainWindow : public CustomWindow {
   void detailCache(const QString &);
   void setBusy(bool on);
   void aboutBox(QWidget *, const QString &, const QString &);
+  void enableToolProjection(bool);
 
  private slots:
   void about();
   void settingsdialog();
   void helpButtonClicked();
   void showDetail(const Cache &);
+  void launchToolRot13();
+  void launchToolProjection();
 
  signals:
   void activated(bool);
@@ -49,7 +53,7 @@ class MainWindow : public CustomWindow {
  private:
   void createMenu();
   bool event(QEvent *);
- 
+
   QGeoServiceProvider *m_serviceProvider;
   MapWidget *m_mapWidget;
   CacheProvider *m_cacheProvider;
@@ -59,6 +63,8 @@ class MainWindow : public CustomWindow {
 
   WaypointDb *m_wptDb;
   int m_lastFlags;
+
+  QAction *m_ActionToolProjection;
 };
 
 #endif
